<TS version="2.1" language="sw">
<context>
    <name>AddressBookPage</name>
    <message>
        <source>Right-click to edit address or label</source>
        <translation type="unfinished">Bofya-kulia ili kuhariri anwani au lebo</translation>
    </message>
    <message>
        <source>Create a new address</source>
        <translation type="unfinished">Tengeneza anwani mpya</translation>
    </message>
    <message>
        <source>&amp;New</source>
        <translation type="unfinished">&amp;Mpya</translation>
    </message>
    <message>
        <source>&amp;Copy</source>
        <translation type="unfinished">&amp;nakili</translation>
    </message>
    <message>
        <source>C&amp;lose</source>
        <translation type="unfinished">C&amp;Funga</translation>
    </message>
    <message>
        <source>Delete the currently selected address from the list</source>
        <translation type="unfinished">Futa anwani iliyochaguliwa sasa kutoka kwenye orodha</translation>
    </message>
    <message>
        <source>Enter address or label to search</source>
        <translation type="unfinished">Weka anwani au chapa ili utafute</translation>
    </message>
    <message>
        <source>Export the data in the current tab to a file</source>
        <translation type="unfinished">Toa data katika kichupo cha sasa hadi kwenye faili</translation>
    </message>
    <message>
        <source>&amp;Export</source>
        <translation type="unfinished">&amp;Toa</translation>
    </message>
    <message>
        <source>&amp;Delete</source>
        <translation type="unfinished">&amp;Futa</translation>
    </message>
    <message>
        <source>Choose the address to send coins to</source>
        <translation type="unfinished">Chagua anwani ya kutuma sarafu</translation>
    </message>
    <message>
        <source>Choose the address to receive coins with</source>
        <translation type="unfinished">Chagua anwani ya kupokea sarafu</translation>
    </message>
    <message>
        <source>C&amp;hoose</source>
        <translation type="unfinished">Chagua</translation>
    </message>
    <message>
        <source>These are your Bitcoin addresses for sending payments. Always check the amount and the receiving address before sending coins.</source>
        <translation type="unfinished">Hizi ndizo anwani zako za kutuma malipo ya sarafu ya Bitcoin. Hakikisha kila wakati kiwango na anwani ya kupokea kabla ya kutuma sarafu.</translation>
    </message>
    <message>
        <source>These are your Bitcoin addresses for receiving payments. Use the 'Create new receiving address' button in the receive tab to create new addresses.
Signing is only possible with addresses of the type 'legacy'.</source>
        <translation type="unfinished">Hizi ndizo anwani zako za Bitcoin za kupokea malipo. Tumia kitufe cha 'Unda anwani mpya ya kupokea' kwenye kichupo cha kupokea ili kuunda anwani mpya.
Kutia sahihi kunawezekana tu kwa anwani za aina ya 'urithi'.</translation>
    </message>
    <message>
        <source>&amp;Copy Address</source>
        <translation type="unfinished">Nakili &amp;anwani</translation>
    </message>
    <message>
        <source>Copy &amp;Label</source>
        <translation type="unfinished">Nakili &amp; Chapa</translation>
    </message>
    <message>
        <source>&amp;Edit</source>
        <translation type="unfinished">&amp; hariri</translation>
    </message>
    <message>
        <source>Export Address List</source>
        <translation type="unfinished">Toa orodha ya anuani</translation>
    </message>
    <message>
        <source>Comma separated file</source>
        <extracomment>Expanded name of the CSV file format. See: https://en.wikipedia.org/wiki/Comma-separated_values.</extracomment>
        <translation type="unfinished">Faili linalotenganishwa kwa mkato</translation>
    </message>
    <message>
        <source>There was an error trying to save the address list to %1. Please try again.</source>
        <extracomment>An error message. %1 is a stand-in argument for the name of the file we attempted to save to.</extracomment>
        <translation type="unfinished">Kulikuwa na kosa jaribu kuokoa orodha ya anwani kwa %1. Tafadhali jaribu tena.</translation>
    </message>
    <message>
        <source>Sending addresses - %1</source>
        <translation type="unfinished">Kutuma anwani - %1</translation>
    </message>
    <message>
        <source>Receiving addresses - %1</source>
        <translation type="unfinished">Kupokea anwani - %1</translation>
    </message>
    <message>
        <source>Exporting Failed</source>
        <translation type="unfinished">Kuuza Nje Kushindwa</translation>
    </message>
</context>
<context>
    <name>AddressTableModel</name>
    <message>
        <source>Label</source>
        <translation type="unfinished">Lebo</translation>
    </message>
    <message>
        <source>Address</source>
        <translation type="unfinished">Anwani</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation type="unfinished">(hakuna lebo)</translation>
    </message>
</context>
<context>
    <name>AskPassphraseDialog</name>
    <message>
        <source>Passphrase Dialog</source>
        <translation type="unfinished">Mazungumzo Ya Maneno Ya Siri</translation>
    </message>
    <message>
        <source>Enter passphrase</source>
        <translation type="unfinished">Ingiza passphrase</translation>
    </message>
    <message>
        <source>New passphrase</source>
        <translation type="unfinished">Nenosiri jipya</translation>
    </message>
    <message>
        <source>Repeat new passphrase</source>
        <translation type="unfinished">Rudia nenosiri jipya</translation>
    </message>
    <message>
        <source>Show passphrase</source>
        <translation type="unfinished">Onyesha nenosiri</translation>
    </message>
    <message>
        <source>Encrypt wallet</source>
        <translation type="unfinished">Simba mkoba</translation>
    </message>
    <message>
        <source>This operation needs your wallet passphrase to unlock the wallet.</source>
        <translation type="unfinished">Operesheni hii inahitaji kaulisiri ya mkoba wako ili kufungua pochi.</translation>
    </message>
    <message>
        <source>Unlock wallet</source>
        <translation type="unfinished">Fungua mkoba</translation>
    </message>
    <message>
        <source>Change passphrase</source>
        <translation type="unfinished">Badilisha nenosiri </translation>
    </message>
    <message>
        <source>Confirm wallet encryption</source>
        <translation type="unfinished">Thibitisha usimbaji fiche wa pochi</translation>
    </message>
    <message>
        <source>Warning: If you encrypt your wallet and lose your passphrase, you will &lt;b&gt;LOSE ALL OF YOUR BITCOINS&lt;/b&gt;!</source>
        <translation type="unfinished">Ilani: Ikiwa utasimba pochi yako na ukapoteza nenosiri lako, &lt;b&gt; UTAPOTEZA BITCOIN ZAKO ZOTE &lt;/b&gt;!</translation>
    </message>
    <message>
        <source>Are you sure you wish to encrypt your wallet?</source>
        <translation type="unfinished">Je, una uhakika ungependa kusimba kibeti chako kwa njia fiche?</translation>
    </message>
    <message>
        <source>Wallet encrypted</source>
        <translation type="unfinished">Wallet imesimbwa kwa njia fiche</translation>
    </message>
    <message>
        <source>Enter the new passphrase for the wallet.&lt;br/&gt;Please use a passphrase of &lt;b&gt;ten or more random characters&lt;/b&gt;, or &lt;b&gt;eight or more words&lt;/b&gt;.</source>
        <translation type="unfinished">Ingiza nenosiri jipya kwa ajili ya pochi yako.&lt;br/&gt;Tafadhali tumia nenosiri la &lt;b&gt;herufi holelaholela kumi au zaidi&lt;/b&gt;, au &lt;b&gt;maneno kumi au zaidi&lt;/b&gt;.</translation>
    </message>
    <message>
        <source>Enter the old passphrase and new passphrase for the wallet.</source>
        <translation type="unfinished">Ingiza nenosiri la zamani na nenosiri jipya la pochi yako.</translation>
    </message>
    <message>
        <source>Continue</source>
        <translation type="unfinished">Endelea</translation>
    </message>
    <message>
        <source>Back</source>
        <translation type="unfinished">Rudi</translation>
    </message>
    <message>
        <source>Remember that encrypting your wallet cannot fully protect your bitcoins from being stolen by malware infecting your computer.</source>
        <translation type="unfinished">Kumbuka kwamba usimbaji fiche wa mkoba wako hauwezi kulinda bitcoins zako zisiibiwe na programu hasidi kuambukiza kompyuta yako.</translation>
    </message>
    <message>
        <source>Wallet to be encrypted</source>
        <translation type="unfinished">Wallet itasimbwa kwa njia fiche</translation>
    </message>
    <message>
        <source>Your wallet is about to be encrypted. </source>
        <translation type="unfinished">Mkoba wako unakaribia kusimbwa kwa njia fiche.</translation>
    </message>
    <message>
        <source>Your wallet is now encrypted. </source>
        <translation type="unfinished">Mkoba wako sasa umesimbwa kwa njia fiche.</translation>
    </message>
    <message>
        <source>IMPORTANT: Any previous backups you have made of your wallet file should be replaced with the newly generated, encrypted wallet file. For security reasons, previous backups of the unencrypted wallet file will become useless as soon as you start using the new, encrypted wallet.</source>
        <translation type="unfinished">MUHIMU: Chelezo zozote ulizofanya hapo awali za faili lako la pochi zinapaswa kubadilishwa na faili mpya ya pochi iliyosimbwa. Kwa sababu za usalama, chelezo za awali za faili la pochi lisilosimbwa zitakuwa hazifai mara tu utakapoanza kutumia pochi mpya iliyosimbwa.
 </translation>
    </message>
    <message>
        <source>Wallet encryption failed</source>
        <translation type="unfinished">Usimbaji fiche wa Wallet haukufaulu</translation>
    </message>
    <message>
        <source>Wallet encryption failed due to an internal error. Your wallet was not encrypted.</source>
        <translation type="unfinished">Usimbaji fiche wa Wallet umeshindwa kwa sababu ya hitilafu ya ndani. Pochi yako haikusimbwa kwa njia fiche.</translation>
    </message>
    <message>
        <source>The supplied passphrases do not match.</source>
        <translation type="unfinished">Nenosiri liliyotolewa haifanani.</translation>
    </message>
    <message>
        <source>The passphrase entered for the wallet decryption was incorrect.</source>
        <translation type="unfinished">Nenosiri liliyoingizwa kwa ajili ya kufungua pochi sio sahihi.</translation>
    </message>
    <message>
        <source>The passphrase entered for the wallet decryption is incorrect. It contains a null character (ie - a zero byte). If the passphrase was set with a version of this software prior to 25.0, please try again with only the characters up to — but not including — the first null character. If this is successful, please set a new passphrase to avoid this issue in the future.</source>
        <translation type="unfinished">Nenosiri lililowekwa kwa ajili ya kusimbua mkoba si sahihi. Ina herufi tupu (yaani - zero byte). Ikiwa kaulisiri iliwekwa na toleo la programu hii kabla ya 25.0, tafadhali jaribu tena na herufi tu hadi - lakini bila kujumuisha - herufi batili ya kwanza. Hili likifanikiwa, tafadhali weka kaulisiri mpya ili kuepuka tatizo hili katika siku zijazo.</translation>
    </message>
    <message>
        <source>Wallet passphrase was successfully changed.</source>
        <translation type="unfinished">Nenosiri la pochi limefanikiwa kubadilishwa.</translation>
    </message>
    <message>
        <source>Passphrase change failed</source>
        <translation type="unfinished">Mabadiliko ya nenosiri hayajafanikiwa</translation>
    </message>
    <message>
        <source>The old passphrase entered for the wallet decryption is incorrect. It contains a null character (ie - a zero byte). If the passphrase was set with a version of this software prior to 25.0, please try again with only the characters up to — but not including — the first null character.</source>
        <translation type="unfinished">Nenosiri la zamani liliyoingizwa kwa ajili ya kufungulia pochi sio sahihi. Linabeba herufi batili (yaani - yenye byte 0 ). Kama nenosiri liliwekwa na toleo la programu hii kabla ya 25.0, tafadhali jaribu tena na herufi zote mpaka — lakini usiweka — herufi batili ya kwanza.</translation>
    </message>
    <message>
        <source>Warning: The Caps Lock key is on!</source>
        <translation type="unfinished">Onyo: Kitufe cha Caps Lock kimewashwa!</translation>
    </message>
</context>
<context>
    <name>BanTableModel</name>
    <message>
        <source>Banned Until</source>
        <translation type="unfinished">Imepigwa Marufuku Hadi</translation>
    </message>
</context>
<context>
    <name>BitcoinApplication</name>
    <message>
        <source>Settings file %1 might be corrupt or invalid.</source>
        <translation type="unfinished">Faili ya mipangilio ya asilimia %1 inaweza kuwa mbovu au batili.</translation>
    </message>
    <message>
        <source>Runaway exception</source>
        <translation type="unfinished">Ubaguzi wa kukimbia</translation>
    </message>
    <message>
        <source>A fatal error occurred. %1 can no longer continue safely and will quit.</source>
        <translation type="unfinished">Kosa kubwa limejitokeza. %1 haliwezi kuendelea salama na litajiondoa.</translation>
    </message>
    <message>
        <source>Internal error</source>
        <translation type="unfinished">Hitilafu ya ndani</translation>
    </message>
    <message>
        <source>An internal error occurred. %1 will attempt to continue safely. This is an unexpected bug which can be reported as described below.</source>
        <translation type="unfinished">Hitilafu ya ndani ilitokea. %1 itajaribu kuendelea salama. Hii ni mdudu usiotarajiwa ambao unaweza kuripotiwa kama ilivyoelezwa hapa chini.</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Do you want to reset settings to default values, or to abort without making changes?</source>
        <extracomment>Explanatory text shown on startup when the settings file cannot be read. Prompts user to make a choice between resetting or aborting.</extracomment>
        <translation type="unfinished">Unataka kurejesha mipangilio kwa thamani za awali, au kusitisha bila kufanya mabadiliko?</translation>
    </message>
    <message>
        <source>A fatal error occurred. Check that settings file is writable, or try running with -nosettings.</source>
        <extracomment>Explanatory text shown on startup when the settings file could not be written. Prompts user to check that we have the ability to write to the file. Explains that the user has the option of running without a settings file.</extracomment>
        <translation type="unfinished">Kosa kubwa limejitokeza. Angalia kwamba faili ya mipangilio inaweza kuandikwa, au jaribu kuendesha na -nosettings.</translation>
    </message>
    <message>
        <source>Error: %1</source>
        <translation type="unfinished">Kosa: %1</translation>
    </message>
    <message>
        <source>%1 didn't yet exit safely…</source>
        <translation type="unfinished">%1 bado hajaondoka salama...</translation>
    </message>
    <message>
        <source>Amount</source>
        <translation type="unfinished">Kiasi</translation>
    </message>
    <message numerus="yes">
        <source>%n second(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n minute(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n hour(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n day(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n week(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n year(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message>
        <source>default wallet</source>
        <translation type="unfinished">mkoba chaguo-msingi</translation>
    </message>
</context>
<context>
    <name>BitcoinGUI</name>
    <message>
        <source>&amp;Overview</source>
        <translation type="unfinished">&amp;Muhtasari</translation>
    </message>
    <message>
        <source>Show general overview of wallet</source>
        <translation type="unfinished">Onyesha muhtasari wa jumla wa mkoba</translation>
    </message>
    <message>
        <source>&amp;Transactions</source>
        <translation type="unfinished">&amp;Shughuli za malipo</translation>
    </message>
    <message>
        <source>Browse transaction history</source>
        <translation type="unfinished">Angalia historia ya shughuli za malipo</translation>
    </message>
    <message>
        <source>Quit application</source>
        <translation type="unfinished">Acha programu</translation>
    </message>
    <message>
        <source>&amp;About %1</source>
        <translation type="unfinished">Kuhusu %1</translation>
    </message>
    <message>
        <source>Show information about %1</source>
        <translation type="unfinished">Onyesha habari kuhusu %1</translation>
    </message>
    <message>
        <source>About &amp;Qt</source>
        <translation type="unfinished">Kuhusu &amp;Qt</translation>
    </message>
    <message>
        <source>Show information about Qt</source>
        <translation type="unfinished">Onyesha habari kuhusu Qt</translation>
    </message>
    <message>
        <source>Modify configuration options for %1</source>
        <translation type="unfinished">Badilisha chaguo za usanidi kwa %1</translation>
    </message>
    <message>
        <source>Create a new wallet</source>
        <translation type="unfinished">Unda mkoba mpya</translation>
    </message>
    <message>
        <source>&amp;Minimize</source>
        <translation type="unfinished">Kupunguza</translation>
    </message>
    <message>
        <source>Wallet:</source>
        <translation type="unfinished">Mkoba:</translation>
    </message>
    <message>
        <source>Network activity disabled.</source>
        <extracomment>A substring of the tooltip.</extracomment>
        <translation type="unfinished">Shughuli ya mtandao imelemazwa.</translation>
    </message>
    <message>
        <source>Proxy is &lt;b&gt;enabled&lt;/b&gt;: %1</source>
        <translation type="unfinished">Proxy &lt;b&gt;imeamilishwa&lt;/b&gt;: %1</translation>
    </message>
    <message>
        <source>Send coins to a Bitcoin address</source>
        <translation type="unfinished">Tuma sarafu kwa anwani ya Bitcoin</translation>
    </message>
    <message>
        <source>Backup wallet to another location</source>
        <translation type="unfinished">Cheleza mkoba hadi eneo lingine</translation>
    </message>
    <message>
        <source>Change the passphrase used for wallet encryption</source>
        <translation type="unfinished">Badilisha nenosiri liliyotumika kusimba pochi</translation>
    </message>
    <message>
        <source>&amp;Send</source>
        <translation type="unfinished">&amp;TUMA</translation>
    </message>
    <message>
        <source>&amp;Receive</source>
        <translation type="unfinished">&amp;Pokea</translation>
    </message>
    <message>
        <source>&amp;Options…</source>
        <translation type="unfinished">&amp;Chaguo...</translation>
    </message>
    <message>
        <source>&amp;Encrypt Wallet…</source>
        <translation type="unfinished">&amp;Simba Mkoba...</translation>
    </message>
    <message>
        <source>Encrypt the private keys that belong to your wallet</source>
        <translation type="unfinished">Funga funguo za siri zinazomiliki mkoba wako.</translation>
    </message>
    <message>
        <source>&amp;Backup Wallet…</source>
        <translation type="unfinished">&amp;Hifadhi Mkoba...
</translation>
    </message>
    <message>
        <source>&amp;Change Passphrase…</source>
        <translation type="unfinished">&amp;Badilisha Nenosiri...</translation>
    </message>
    <message>
        <source>Sign &amp;message…</source>
        <translation type="unfinished">Saini &amp;ujumbe...</translation>
    </message>
    <message>
        <source>Sign messages with your Bitcoin addresses to prove you own them</source>
        <translation type="unfinished">Saini ujumbe na anwani zako za Bitcoin ili kuthibitisha umiliki wao.</translation>
    </message>
    <message>
        <source>&amp;Verify message…</source>
        <translation type="unfinished">&amp;Thibitisha ujumbe...</translation>
    </message>
    <message>
        <source>Verify messages to ensure they were signed with specified Bitcoin addresses</source>
        <translation type="unfinished">Hakikisha ujumbe umethibitishwa kuwa ulisainiwa na anwani za Bitcoin zilizotajwa</translation>
    </message>
    <message>
        <source>&amp;Load PSBT from file…</source>
        <translation type="unfinished">&amp;Pakia PSBT kutoka faili...</translation>
    </message>
    <message>
        <source>Open &amp;URI…</source>
        <translation type="unfinished">Fungua &amp;URI ...</translation>
    </message>
    <message>
        <source>Close Wallet…</source>
        <translation type="unfinished">Funga pochi</translation>
    </message>
    <message>
        <source>Create Wallet…</source>
        <translation type="unfinished">Unda pochi</translation>
    </message>
    <message>
        <source>Close All Wallets…</source>
        <translation type="unfinished">Funga pochi yzote</translation>
    </message>
    <message>
        <source>&amp;File</source>
        <translation type="unfinished">&amp;Faili</translation>
    </message>
    <message>
        <source>&amp;Settings</source>
        <translation type="unfinished">&amp;Vipimo</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation type="unfinished">&amp;Msaidie</translation>
    </message>
    <message>
        <source>Tabs toolbar</source>
        <translation type="unfinished">Vidirisha vya vichupo</translation>
    </message>
    <message>
        <source>Syncing Headers (%1%)…</source>
        <translation type="unfinished">Kuunganisha Vichwa vya habari (%1%) ...</translation>
    </message>
    <message>
        <source>Synchronizing with network…</source>
        <translation type="unfinished">Kuunganisha na mtandao ...</translation>
    </message>
    <message>
        <source>Indexing blocks on disk…</source>
        <translation type="unfinished">Kuweka alama za vitengo kwenye diski ...</translation>
    </message>
    <message>
        <source>Processing blocks on disk…</source>
        <translation type="unfinished">Kusindika vitalu kwenye diski ...</translation>
    </message>
    <message>
        <source>Connecting to peers…</source>
        <translation type="unfinished">Kuunganisha na wenzako wa kushirikiana...</translation>
    </message>
    <message>
        <source>Request payments (generates QR codes and bitcoin: URIs)</source>
        <translation type="unfinished">Omba malipo (huzalisha nambari za QR na bitcoin: URIs)</translation>
    </message>
    <message>
        <source>Show the list of used sending addresses and labels</source>
        <translation type="unfinished">Onyesha orodha ya anuani za kutuma zilizotumika na chapa</translation>
    </message>
    <message>
        <source>Show the list of used receiving addresses and labels</source>
        <translation type="unfinished">Onyesha orodha ya anuani za kupokea zilizotumika na chapa</translation>
    </message>
    <message>
        <source>&amp;Command-line options</source>
        <translation type="unfinished">&amp;Chaguo za amri ya amri</translation>
    </message>
    <message numerus="yes">
        <source>Processed %n block(s) of transaction history.</source>
        <translation type="unfinished">
            <numerusform>Imechakatwa %n block(s) za historia ya muamala.</numerusform>
            <numerusform>Imechakatwa %n block(s) za historia ya muamala.</numerusform>
        </translation>
    </message>
    <message>
        <source>%1 behind</source>
        <translation type="unfinished">%1 nyuma</translation>
    </message>
    <message>
        <source>Catching up…</source>
        <translation type="unfinished">Inakamata...</translation>
    </message>
    <message>
        <source>Transactions after this will not yet be visible.</source>
        <translation type="unfinished">Shughuli baada ya hii bado hazitaonekana.</translation>
    </message>
    <message>
        <source>Error</source>
        <translation type="unfinished">Kosa</translation>
    </message>
    <message>
        <source>Warning</source>
        <translation type="unfinished">Onyo</translation>
    </message>
    <message>
        <source>Information</source>
        <translation type="unfinished">Habari</translation>
    </message>
    <message>
        <source>Up to date</source>
        <translation type="unfinished">Imesasishwa</translation>
    </message>
    <message>
        <source>Load Partially Signed Bitcoin Transaction</source>
        <translation type="unfinished">Pakia Muamala wa Bitcoin Uliosainiwa Kiasi</translation>
    </message>
    <message>
        <source>Load PSBT from &amp;clipboard…</source>
        <translation type="unfinished">Pakia PSBT kutoka &amp;clipboard...</translation>
    </message>
    <message>
        <source>Load Partially Signed Bitcoin Transaction from clipboard</source>
        <translation type="unfinished">Pakia Muamala wa Bitcoin Uliosainiwa Kiasi kutoka kwenye ubao wa kunakili</translation>
    </message>
    <message>
        <source>Node window</source>
        <translation type="unfinished">Dirisha la nodi</translation>
    </message>
    <message>
        <source>Open node debugging and diagnostic console</source>
        <translation type="unfinished">Fungua utatuzi wa nodi na koni ya uchunguzi</translation>
    </message>
    <message>
        <source>&amp;Sending addresses</source>
        <translation type="unfinished">&amp;Anwani za kutuma</translation>
    </message>
    <message>
        <source>&amp;Receiving addresses</source>
        <translation type="unfinished">&amp;Inapokea anwani</translation>
    </message>
    <message>
        <source>Open a bitcoin: URI</source>
        <translation type="unfinished">Fungua bitcoin: URI</translation>
    </message>
    <message>
        <source>Open Wallet</source>
        <translation type="unfinished">Fungua Pochi</translation>
    </message>
    <message>
        <source>Open a wallet</source>
        <translation type="unfinished">Fungua pochi</translation>
    </message>
    <message>
        <source>Close wallet</source>
        <translation type="unfinished">Funga pochi</translation>
    </message>
    <message>
        <source>Restore Wallet…</source>
        <extracomment>Name of the menu item that restores wallet from a backup file.</extracomment>
        <translation type="unfinished">Rejesha Pochi...</translation>
    </message>
    <message>
        <source>Restore a wallet from a backup file</source>
        <extracomment>Status tip for Restore Wallet menu item</extracomment>
        <translation type="unfinished">Rejesha mkoba kutoka kwa faili ya chelezo</translation>
    </message>
    <message>
        <source>Close all wallets</source>
        <translation type="unfinished">Funga pochi zote</translation>
    </message>
    <message>
        <source>Migrate Wallet</source>
        <translation type="unfinished">Hamisha Pochi</translation>
    </message>
    <message>
        <source>Migrate a wallet</source>
        <translation type="unfinished">Hamisha mkoba</translation>
    </message>
    <message>
        <source>Show the %1 help message to get a list with possible Bitcoin command-line options</source>
        <translation type="unfinished">Onyesha %1 ujumbe wa usaidizi ili kupata orodha na chaguo zinazowezekana za mstari wa amri za Bitcoin</translation>
    </message>
    <message>
        <source>&amp;Mask values</source>
        <translation type="unfinished">&amp;Funga maadili</translation>
    </message>
    <message>
        <source>Mask the values in the Overview tab</source>
        <translation type="unfinished">Ficha maadili kwenye kichupo cha Muhtasari</translation>
    </message>
    <message>
        <source>No wallets available</source>
        <translation type="unfinished">Hakuna pochi zinazopatikana</translation>
    </message>
    <message>
        <source>Wallet Data</source>
        <extracomment>Name of the wallet data file format.</extracomment>
        <translation type="unfinished">Data ya Pochi</translation>
    </message>
    <message>
        <source>Load Wallet Backup</source>
        <extracomment>The title for Restore Wallet File Windows</extracomment>
        <translation type="unfinished">Pakia Hifadhi Nakala ya Wallet</translation>
    </message>
    <message>
        <source>Restore Wallet</source>
        <extracomment>Title of pop-up window shown when the user is attempting to restore a wallet.</extracomment>
        <translation type="unfinished">Rejesha Pochi</translation>
    </message>
    <message>
        <source>Wallet Name</source>
        <extracomment>Label of the input field where the name of the wallet is entered.</extracomment>
        <translation type="unfinished">Jina la Wallet</translation>
    </message>
    <message>
        <source>&amp;Window</source>
        <translation type="unfinished">&amp;Dirisha</translation>
    </message>
    <message>
        <source>Zoom</source>
        <translation type="unfinished">Kuza</translation>
    </message>
    <message>
        <source>Main Window</source>
        <translation type="unfinished">Dirisha Kuu</translation>
    </message>
    <message>
        <source>%1 client</source>
        <translation type="unfinished">%1 mteja</translation>
    </message>
    <message>
        <source>&amp;Hide</source>
        <translation type="unfinished">&amp;Ficha</translation>
    </message>
    <message>
        <source>S&amp;how</source>
        <translation type="unfinished">Jinsi &amp; jinsi</translation>
    </message>
    <message numerus="yes">
        <source>%n active connection(s) to Bitcoin network.</source>
        <extracomment>A substring of the tooltip.</extracomment>
        <translation type="unfinished">
            <numerusform>miunganisho %n inayotumika kwa mtandao wa Bitcoin.</numerusform>
            <numerusform>miunganisho %ninayotumika kwa mtandao wa Bitcoin.</numerusform>
        </translation>
    </message>
    <message>
        <source>Click for more actions.</source>
        <extracomment>A substring of the tooltip. "More actions" are available via the context menu.</extracomment>
        <translation type="unfinished">Bofya kwa vitendo zaidi.</translation>
    </message>
    <message>
        <source>Show Peers tab</source>
        <extracomment>A context menu item. The "Peers tab" is an element of the "Node window".</extracomment>
        <translation type="unfinished">Onyesha kichupo cha Marika</translation>
    </message>
    <message>
        <source>Disable network activity</source>
        <extracomment>A context menu item.</extracomment>
        <translation type="unfinished">Zima shughuli za mtandao</translation>
    </message>
    <message>
        <source>Enable network activity</source>
        <extracomment>A context menu item. The network activity was disabled previously.</extracomment>
        <translation type="unfinished">Washa shughuli za mtandao</translation>
    </message>
    <message>
        <source>Pre-syncing Headers (%1%)…</source>
        <translation type="unfinished">Kusawazisha Vichwa vya awali (%1%)...</translation>
    </message>
    <message>
        <source>Error: %1</source>
        <translation type="unfinished">Kosa: %1</translation>
    </message>
    <message>
        <source>Warning: %1</source>
        <translation type="unfinished">Onyo: %1</translation>
    </message>
    <message>
        <source>Date: %1
</source>
        <translation type="unfinished">Tarehe: %1</translation>
    </message>
    <message>
        <source>Amount: %1
</source>
        <translation type="unfinished">Kiasi: %1
</translation>
    </message>
    <message>
        <source>Wallet: %1
</source>
        <translation type="unfinished">Pochi: %1
</translation>
    </message>
    <message>
        <source>Type: %1
</source>
        <translation type="unfinished">Aina: %1</translation>
    </message>
    <message>
        <source>Label: %1
</source>
        <translation type="unfinished">Chapa: %1
</translation>
    </message>
    <message>
        <source>Address: %1
</source>
        <translation type="unfinished">Anwani: %1
</translation>
    </message>
    <message>
        <source>Sent transaction</source>
        <translation type="unfinished">Umetuma muamala</translation>
    </message>
    <message>
        <source>Incoming transaction</source>
        <translation type="unfinished">Muamala unaoingia</translation>
    </message>
    <message>
        <source>HD key generation is &lt;b&gt;enabled&lt;/b&gt;</source>
        <translation type="unfinished">Uzalishaji wa ufunguo wa HD ni &lt;b&gt;kuwezeshwa &lt;/b&gt;</translation>
    </message>
    <message>
        <source>HD key generation is &lt;b&gt;disabled&lt;/b&gt;</source>
        <translation type="unfinished">Uzalishaji wa ufunguo wa HD ni &lt;b&gt;kutowezeshwa&lt;/b&gt;</translation>
    </message>
    <message>
        <source>Private key &lt;b&gt;disabled&lt;/b&gt;</source>
        <translation type="unfinished">Ufunguo wa kibinafsi &lt;b&gt; umezimwa &lt;/b&gt;</translation>
    </message>
    <message>
        <source>Wallet is &lt;b&gt;encrypted&lt;/b&gt; and currently &lt;b&gt;unlocked&lt;/b&gt;</source>
        <translation type="unfinished">Pochi &lt;b&gt;imesimbwa kwa njia fiche&lt;/b&gt; na &lt;b&gt;imefunguliwa&lt;/b&gt; kwa sasa</translation>
    </message>
    <message>
        <source>Wallet is &lt;b&gt;encrypted&lt;/b&gt; and currently &lt;b&gt;locked&lt;/b&gt;</source>
        <translation type="unfinished">Pochi &lt;b&gt;imesimbwa kwa njia fiche&lt;/b&gt; na &lt;b&gt;imefungwa&lt;/b&gt;kwa sasa</translation>
    </message>
    <message>
        <source>Original message:</source>
        <translation type="unfinished">Ujumbe asilia:</translation>
    </message>
</context>
<context>
    <name>UnitDisplayStatusBarControl</name>
    <message>
        <source>Unit to show amounts in. Click to select another unit.</source>
        <translation type="unfinished">Kipimo cha kuonyesha kiasi. Bofya ili kuchagua kitengo kingine.</translation>
    </message>
</context>
<context>
    <name>CoinControlDialog</name>
    <message>
        <source>Coin Selection</source>
        <translation type="unfinished">Uteuzi wa Sarafu</translation>
    </message>
    <message>
        <source>Quantity:</source>
        <translation type="unfinished">Wingi</translation>
    </message>
    <message>
        <source>Bytes:</source>
        <translation type="unfinished">Baiti:</translation>
    </message>
    <message>
        <source>Amount:</source>
        <translation type="unfinished">Kiasi:</translation>
    </message>
    <message>
        <source>Fee:</source>
        <translation type="unfinished">Ada:</translation>
    </message>
    <message>
        <source>After Fee:</source>
        <translation type="unfinished">Baada ya Ada</translation>
    </message>
    <message>
        <source>Change:</source>
        <translation type="unfinished">Badilisha:</translation>
    </message>
    <message>
        <source>(un)select all</source>
        <translation type="unfinished">(acha) kuchagua zote</translation>
    </message>
    <message>
        <source>Tree mode</source>
        <translation type="unfinished">Hali ya mti</translation>
    </message>
    <message>
        <source>List mode</source>
        <translation type="unfinished">Hali ya orodha</translation>
    </message>
    <message>
        <source>Amount</source>
        <translation type="unfinished">Kiasi</translation>
    </message>
    <message>
        <source>Received with label</source>
        <translation type="unfinished">Imepokelewa na chapa</translation>
    </message>
    <message>
        <source>Received with address</source>
        <translation type="unfinished">Imepokelewa na anwani</translation>
    </message>
    <message>
        <source>Date</source>
        <translation type="unfinished">Tarehe</translation>
    </message>
    <message>
        <source>Confirmations</source>
        <translation type="unfinished">Uthibitisho</translation>
    </message>
    <message>
        <source>Confirmed</source>
        <translation type="unfinished">Imethibitishwa</translation>
    </message>
    <message>
        <source>Copy amount</source>
        <translation type="unfinished">Nakili kiasi</translation>
    </message>
    <message>
        <source>&amp;Copy address</source>
        <translation type="unfinished">&amp;Nakili anwani</translation>
    </message>
    <message>
        <source>Copy &amp;label</source>
        <translation type="unfinished">Nakili &amp;chapa</translation>
    </message>
    <message>
        <source>Copy &amp;amount</source>
        <translation type="unfinished">Nakili &amp;kiasi</translation>
    </message>
    <message>
        <source>Copy transaction &amp;ID and output index</source>
        <translation type="unfinished">Nakili &amp;Kitambulisho cha muamala na faharasa ya matokeo</translation>
    </message>
    <message>
        <source>L&amp;ock unspent</source>
        <translation type="unfinished">&amp;Funga ambayo haijatumika</translation>
    </message>
    <message>
        <source>&amp;Unlock unspent</source>
        <translation type="unfinished">&amp;Fungua ambayo haijatumika</translation>
    </message>
    <message>
        <source>Copy quantity</source>
        <translation type="unfinished">Nakili wingi</translation>
    </message>
    <message>
        <source>Copy fee</source>
        <translation type="unfinished">Ada ya nakala</translation>
    </message>
    <message>
        <source>Copy after fee</source>
        <translation type="unfinished">Nakili baada ya ada</translation>
    </message>
    <message>
        <source>Copy bytes</source>
        <translation type="unfinished">Nakili baiti</translation>
    </message>
    <message>
        <source>Copy change</source>
        <translation type="unfinished">Nakili mabadiliko</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation type="unfinished">(hamna chapa)</translation>
    </message>
    <message>
        <source>(change)</source>
        <translation type="unfinished">(badilisha)</translation>
    </message>
</context>
<context>
    <name>CreateWalletActivity</name>
    <message>
        <source>Create Wallet</source>
        <extracomment>Title of window indicating the progress of creation of a new wallet.</extracomment>
        <translation type="unfinished">Unda Pochi</translation>
    </message>
    <message>
        <source>Create wallet failed</source>
        <translation type="unfinished">Imeshindwa kuunda pochi</translation>
    </message>
    <message>
        <source>Create wallet warning</source>
        <translation type="unfinished">Unda onyo la pochi</translation>
    </message>
    <message>
        <source>Can't list signers</source>
        <translation type="unfinished">Haiwezi kuorodhesha waliotia sahihi</translation>
    </message>
    <message>
        <source>Too many external signers found</source>
        <translation type="unfinished">Watia saini wengi wa nje wamepatikana</translation>
    </message>
</context>
<context>
    <name>LoadWalletsActivity</name>
    <message>
        <source>Load Wallets</source>
        <extracomment>Title of progress window which is displayed when wallets are being loaded.</extracomment>
        <translation type="unfinished">Pakia Pochi</translation>
    </message>
    <message>
        <source>Loading wallets…</source>
        <extracomment>Descriptive text of the load wallets progress window which indicates to the user that wallets are currently being loaded.</extracomment>
        <translation type="unfinished">Inapakia pochi...</translation>
    </message>
</context>
<context>
    <name>MigrateWalletActivity</name>
    <message>
        <source>Migrate wallet</source>
        <translation type="unfinished">Hamisha pochi</translation>
    </message>
    <message>
        <source>Are you sure you wish to migrate the wallet &lt;i&gt;%1&lt;/i&gt;?</source>
        <translation type="unfinished">Je una uhakika ungependa kuhamisha pochi&lt;i&gt;%1&lt;/i&gt;?</translation>
    </message>
    <message>
        <source>Migrating the wallet will convert this wallet to one or more descriptor wallets. A new wallet backup will need to be made.
If this wallet contains any watchonly scripts, a new wallet will be created which contains those watchonly scripts.
If this wallet contains any solvable but not watched scripts, a different and new wallet will be created which contains those scripts.

The migration process will create a backup of the wallet before migrating. This backup file will be named &lt;wallet name&gt;-&lt;timestamp&gt;.legacy.bak and can be found in the directory for this wallet. In the event of an incorrect migration, the backup can be restored with the "Restore Wallet" functionality.</source>
        <translation type="unfinished">Kuhamisha pochi kutabadilisha pochi hii hadi pochi moja au zaidi za kifafanuzi. Nakala mpya ya mkoba itahitaji kufanywa.
Ikiwa pochi hii ina hati zozote za kutazama pekee, pochi mpya itaundwa ambayo ina hati hizo za kutazama pekee.
Ikiwa pochi hii ina hati zinazoweza kutengenezea lakini zisizotazamwa, pochi tofauti na mpya itaundwa ambayo ina hati hizo.

Mchakato wa uhamiaji utaunda nakala rudufu ya pochi kabla ya kuhama. Faili hii ya chelezo itaitwa &lt;wallet name&gt;-&lt;timestamp&gt;.legacy.bak na inaweza kupatikana katika saraka ya pochi hii. Katika tukio la uhamiaji usio sahihi, hifadhi inaweza kurejeshwa na utendaji wa "Rejesha Wallet".</translation>
    </message>
    <message>
        <source>Migrate Wallet</source>
        <translation type="unfinished">Hamisha Pochi</translation>
    </message>
    <message>
        <source>Migration failed</source>
        <translation type="unfinished">Uhamiaji haukufaulu</translation>
    </message>
    <message>
        <source>Migration Successful</source>
        <translation type="unfinished">Uhamiaji Umefaulu</translation>
    </message>
</context>
<context>
    <name>OpenWalletActivity</name>
    <message>
        <source>Open wallet failed</source>
        <translation type="unfinished">Imeshindwa kufungua pochi</translation>
    </message>
    <message>
        <source>Open wallet warning</source>
        <translation type="unfinished">Fungua onyo la pochi</translation>
    </message>
    <message>
        <source>Open Wallet</source>
        <extracomment>Title of window indicating the progress of opening of a wallet.</extracomment>
        <translation type="unfinished">Fungua Pochi</translation>
    </message>
    </context>
<context>
    <name>RestoreWalletActivity</name>
    <message>
        <source>Restore Wallet</source>
        <extracomment>Title of progress window which is displayed when wallets are being restored.</extracomment>
        <translation type="unfinished">Rejesha Pochi</translation>
    </message>
    <message>
        <source>Restore wallet failed</source>
        <extracomment>Title of message box which is displayed when the wallet could not be restored.</extracomment>
        <translation type="unfinished">Kurejesha pochi kumeshindwa</translation>
    </message>
    <message>
        <source>Restore wallet warning</source>
        <extracomment>Title of message box which is displayed when the wallet is restored with some warning.</extracomment>
        <translation type="unfinished">Rejesha onyo la pochi</translation>
    </message>
    <message>
        <source>Restore wallet message</source>
        <extracomment>Title of message box which is displayed when the wallet is successfully restored.</extracomment>
        <translation type="unfinished">Rejesha ujumbe wa pochi</translation>
    </message>
</context>
<context>
    <name>WalletController</name>
    <message>
        <source>Close wallet</source>
        <translation type="unfinished">Funga pochi</translation>
    </message>
    <message>
        <source>Are you sure you wish to close the wallet &lt;i&gt;%1&lt;/i&gt;?</source>
        <translation type="unfinished">Je una uhakika ungependa kufunga pochi&lt;i&gt;%1&lt;/i&gt;?</translation>
    </message>
    <message>
        <source>Closing the wallet for too long can result in having to resync the entire chain if pruning is enabled.</source>
        <translation type="unfinished">Kufunga pochi kwa muda mrefu sana kunaweza kusababisha kusawazisha tena mnyororo mzima ikiwa upogoaji umewezeshwa.</translation>
    </message>
    <message>
        <source>Close all wallets</source>
        <translation type="unfinished">Funga pochi zote</translation>
    </message>
    <message>
        <source>Are you sure you wish to close all wallets?</source>
        <translation type="unfinished">Je una uhakika ungependa kufunga pochi zote?</translation>
    </message>
</context>
<context>
    <name>CreateWalletDialog</name>
    <message>
        <source>Create Wallet</source>
        <translation type="unfinished">Unda Pochi</translation>
    </message>
    <message>
        <source>You are one step away from creating your new wallet!</source>
        <translation type="unfinished">Umebakiza hatua moja ili kuunda pochi yako mpya!</translation>
    </message>
    <message>
        <source>Please provide a name and, if desired, enable any advanced options</source>
        <translation type="unfinished">Tafadhali toa jina na, ikihitajika, wezesha chaguo zozote za kina</translation>
    </message>
    <message>
        <source>Wallet Name</source>
        <translation type="unfinished">Jina la Wallet</translation>
    </message>
    <message>
        <source>Wallet</source>
        <translation type="unfinished">Pochi</translation>
    </message>
    <message>
        <source>Encrypt the wallet. The wallet will be encrypted with a passphrase of your choice.</source>
        <translation type="unfinished">Simba pochi. Pochi itasimbwa kwa kutumia nenosiri utakalo chagua.</translation>
    </message>
    <message>
        <source>Disable private keys for this wallet. Wallets with private keys disabled will have no private keys and cannot have an HD seed or imported private keys. This is ideal for watch-only wallets.</source>
        <translation type="unfinished">Zima funguo za siri kwa ajili ya pochi hii. Pochi zenye funguo za siri zilizozimwa hazitakua na funguo za siri na hazitakuwa na mbegu ya HD au funguo za siri zilizoingizwa. Hii inafaa kwa pochi za uangalizi tu.</translation>
    </message>
    <message>
        <source>Make a blank wallet. Blank wallets do not initially have private keys or scripts. Private keys and addresses can be imported, or an HD seed can be set, at a later time.</source>
        <translation type="unfinished">Tengeneza pochi tupu. Pochi tupu kwa kuanza hazina funguo za siri au hati. Funguo za siri zinaweza kuingizwa, au mbegu ya HD inaweza kuwekwa baadae.</translation>
    </message>
    <message>
        <source>Use an external signing device such as a hardware wallet. Configure the external signer script in wallet preferences first.</source>
        <translation type="unfinished">Tumia kifaa cha kutia sahihi cha nje kama vile pochi ya maunzi. Sanidi hati ya kutia sahihi ya nje katika mapendeleo ya pochi kwanza.</translation>
    </message>
    <message>
        <source>Create</source>
        <translation type="unfinished">Unda</translation>
    </message>
    </context>
<context>
    <name>EditAddressDialog</name>
    <message>
        <source>&amp;Label</source>
        <translation type="unfinished">&amp;Chapa</translation>
    </message>
    <message>
        <source>The label associated with this address list entry</source>
        <translation type="unfinished">Chapa inayohusiana na hiki kipendele cha orodha ya anuani</translation>
    </message>
    <message>
        <source>Edit sending address</source>
        <translation type="unfinished">Badilisha anwani ya kutuma</translation>
    </message>
    <message>
        <source>Address "%1" already exists as a receiving address with label "%2" and so cannot be added as a sending address.</source>
        <translation type="unfinished">Anuani "%1" ipo teyari kama anuani ya kupokea ikiwa na chapa "%2" hivyo haiwezi kuongezwa kama anuani ya kutuma.</translation>
    </message>
    <message>
        <source>The entered address "%1" is already in the address book with label "%2".</source>
        <translation type="unfinished">Anuani iliyoingizwa "%1" teyari ipo kwenye kitabu cha anuani ikiwa na chapa "%2".</translation>
    </message>
    <message>
        <source>Could not unlock wallet.</source>
        <translation type="unfinished">Haikuweza kufungua pochi.</translation>
    </message>
    <message>
        <source>New key generation failed.</source>
        <translation type="unfinished">Uzalishaji mpya wa ufunguo umeshindwa.</translation>
    </message>
</context>
<context>
    <name>FreespaceChecker</name>
    <message>
        <source>A new data directory will be created.</source>
        <translation type="unfinished">Saraka mpya ya data itaundwa.</translation>
    </message>
    <message>
        <source>name</source>
        <translation type="unfinished">Jina</translation>
    </message>
    <message>
        <source>Path already exists, and is not a directory.</source>
        <translation type="unfinished">Njia tayari ipo, na si saraka.</translation>
    </message>
    <message>
        <source>Cannot create data directory here.</source>
        <translation type="unfinished">Haiwezi kuunda saraka ya data hapa.</translation>
    </message>
</context>
<context>
    <name>Intro</name>
    <message>
        <source>Welcome</source>
        <translation type="unfinished">Karibu</translation>
    </message>
    <message numerus="yes">
        <source>%n GB of space available</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>(of %n GB needed)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>(%n GB needed for full chain)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>(sufficient to restore backups %n day(s) old)</source>
        <extracomment>Explanatory text on the capability of the current prune target.</extracomment>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message>
        <source>Error</source>
        <translation type="unfinished">Onyo</translation>
    </message>
</context>
<context>
    <name>OptionsDialog</name>
    <message>
        <source>&amp;Window</source>
        <translation type="unfinished">&amp;Dirisha</translation>
    </message>
    <message>
        <source>Continue</source>
        <translation type="unfinished">Endelea</translation>
    </message>
    <message>
        <source>Error</source>
        <translation type="unfinished">Onyo</translation>
    </message>
    </context>
<context>
    <name>PeerTableModel</name>
    <message>
        <source>Address</source>
        <extracomment>Title of Peers Table column which contains the IP/Onion/I2P address of the connected peer.</extracomment>
        <translation type="unfinished">Anuani</translation>
    </message>
    </context>
<context>
    <name>QRImageWidget</name>
    <message>
        <source>Resulting URI too long, try to reduce the text for label / message.</source>
        <translation type="unfinished">URI inayotokea ni ndefu sana. Jaribu kupunguza maandishi ya chapa / ujumbe.</translation>
    </message>
    </context>
<context>
    <name>RPCConsole</name>
    <message>
        <source>Node window</source>
        <translation type="unfinished">Dirisha la nodi</translation>
    </message>
    <message>
        <source>&amp;Copy address</source>
        <extracomment>Context menu action to copy the address of a peer.</extracomment>
        <translation type="unfinished">&amp;Nakili anwani</translation>
    </message>
    </context>
<context>
    <name>ReceiveCoinsDialog</name>
    <message>
        <source>&amp;Label:</source>
        <translation type="unfinished">&amp;Chapa:</translation>
    </message>
    <message>
        <source>An optional label to associate with the new receiving address.</source>
        <translation type="unfinished">Chapa ya hiari kuhusisha na anuani mpya ya kupokea.</translation>
    </message>
    <message>
        <source>An optional label to associate with the new receiving address (used by you to identify an invoice).  It is also attached to the payment request.</source>
        <translation type="unfinished">Chapa ya hiari kuhusisha na anuani mpya ya kupokea (hutumika na wewe kutambua ankara). Pia huambatanishwa kwenye ombi la malipo.</translation>
    </message>
    <message>
        <source>&amp;Copy address</source>
        <translation type="unfinished">&amp;Nakili anwani</translation>
    </message>
    <message>
        <source>Copy &amp;label</source>
        <translation type="unfinished">Nakili &amp;chapa</translation>
    </message>
    <message>
        <source>Copy &amp;amount</source>
        <translation type="unfinished">Nakili &amp;kiasi</translation>
    </message>
    <message>
        <source>Could not unlock wallet.</source>
        <translation type="unfinished">Haikuweza kufungua pochi.</translation>
    </message>
    </context>
<context>
    <name>ReceiveRequestDialog</name>
    <message>
        <source>Amount:</source>
        <translation type="unfinished">Kiasi:</translation>
    </message>
    <message>
        <source>Label:</source>
        <translation type="unfinished">Chapa:</translation>
    </message>
    <message>
        <source>Wallet:</source>
        <translation type="unfinished">Mkoba:</translation>
    </message>
    </context>
<context>
    <name>RecentRequestsTableModel</name>
    <message>
        <source>Date</source>
        <translation type="unfinished">Tarehe</translation>
    </message>
    <message>
        <source>Label</source>
        <translation type="unfinished">Chapa</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation type="unfinished">(hamna chapa)</translation>
    </message>
    </context>
<context>
    <name>SendCoinsDialog</name>
    <message>
        <source>Quantity:</source>
        <translation type="unfinished">Wingi</translation>
    </message>
    <message>
        <source>Bytes:</source>
        <translation type="unfinished">Baiti:</translation>
    </message>
    <message>
        <source>Amount:</source>
        <translation type="unfinished">Kiasi:</translation>
    </message>
    <message>
        <source>Fee:</source>
        <translation type="unfinished">Ada:</translation>
    </message>
    <message>
        <source>After Fee:</source>
        <translation type="unfinished">Baada ya Ada</translation>
    </message>
    <message>
        <source>Change:</source>
        <translation type="unfinished">Badilisha:</translation>
    </message>
    <message>
        <source>Copy quantity</source>
        <translation type="unfinished">Nakili wingi</translation>
    </message>
    <message>
        <source>Copy amount</source>
        <translation type="unfinished">Nakili kiasi</translation>
    </message>
    <message>
        <source>Copy fee</source>
        <translation type="unfinished">Ada ya nakala</translation>
    </message>
    <message>
        <source>Copy after fee</source>
        <translation type="unfinished">Nakili baada ya ada</translation>
    </message>
    <message>
        <source>Copy bytes</source>
        <translation type="unfinished">Nakili baiti</translation>
    </message>
    <message>
        <source>Copy change</source>
        <translation type="unfinished">Nakili mabadiliko</translation>
    </message>
    <message numerus="yes">
        <source>Estimated to begin confirmation within %n block(s).</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation type="unfinished">(hamna chapa)</translation>
    </message>
</context>
<context>
    <name>SendCoinsEntry</name>
    <message>
        <source>&amp;Label:</source>
        <translation type="unfinished">&amp;Chapa:</translation>
    </message>
    <message>
        <source>Enter a label for this address to add it to the list of used addresses</source>
        <translation type="unfinished">Ingiza chapa kwa ajili ya anuani hii kuiongeza katika orodha ya anuani zilizotumika</translation>
    </message>
    </context>
<context>
    <name>TransactionDesc</name>
    <message>
        <source>Date</source>
        <translation type="unfinished">Tarehe</translation>
    </message>
    <message>
        <source>label</source>
        <translation type="unfinished">chapa</translation>
    </message>
    <message numerus="yes">
        <source>matures in %n more block(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message>
        <source>Amount</source>
        <translation type="unfinished">Kiasi</translation>
    </message>
    </context>
<context>
    <name>TransactionTableModel</name>
    <message>
        <source>Date</source>
        <translation type="unfinished">Tarehe</translation>
    </message>
    <message>
        <source>Label</source>
        <translation type="unfinished">Chapa</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation type="unfinished">(hakuna lebo)</translation>
    </message>
    </context>
<context>
    <name>TransactionView</name>
    <message>
        <source>Enter address, transaction id, or label to search</source>
        <translation type="unfinished">Ingiza anuani, kitambulisho cha muamala, au chapa kutafuta</translation>
    </message>
    <message>
        <source>&amp;Copy address</source>
        <translation type="unfinished">&amp;Nakili anwani</translation>
    </message>
    <message>
        <source>Copy &amp;label</source>
        <translation type="unfinished">Nakili &amp;chapa</translation>
    </message>
    <message>
        <source>Copy &amp;amount</source>
        <translation type="unfinished">Nakili &amp;kiasi</translation>
    </message>
    <message>
        <source>&amp;Edit address label</source>
        <translation type="unfinished">&amp;Hariri chapa ya anuani</translation>
    </message>
    <message>
        <source>Export Transaction History</source>
        <translation type="unfinished">Toa Historia ya Miamala</translation>
    </message>
    <message>
        <source>Comma separated file</source>
        <extracomment>Expanded name of the CSV file format. See: https://en.wikipedia.org/wiki/Comma-separated_values.</extracomment>
        <translation type="unfinished">Faili linalotenganishwa kwa mkato</translation>
    </message>
    <message>
        <source>Confirmed</source>
        <translation type="unfinished">Imethibitishwa</translation>
    </message>
    <message>
        <source>Date</source>
        <translation type="unfinished">Tarehe</translation>
    </message>
    <message>
        <source>Label</source>
        <translation type="unfinished">Chapa</translation>
    </message>
    <message>
        <source>Address</source>
        <translation type="unfinished">Anwani</translation>
    </message>
    <message>
        <source>Exporting Failed</source>
        <translation type="unfinished">Kuuza Nje Kushindwa</translation>
    </message>
    <message>
        <source>Exporting Successful</source>
        <translation type="unfinished">Utoaji Umefanikiwa</translation>
    </message>
    </context>
<context>
    <name>WalletFrame</name>
    <message>
        <source>Create a new wallet</source>
        <translation type="unfinished">Unda mkoba mpya</translation>
    </message>
    <message>
        <source>Error</source>
        <translation type="unfinished">Onyo</translation>
    </message>
    </context>
<context>
    <name>WalletView</name>
    <message>
        <source>&amp;Export</source>
        <translation type="unfinished">&amp;Toa</translation>
    </message>
    <message>
        <source>Export the data in the current tab to a file</source>
        <translation type="unfinished">Toa data katika kichupo cha sasa hadi kwenye faili</translation>
    </message>
    <message>
        <source>Wallet Data</source>
        <extracomment>Name of the wallet data file format.</extracomment>
        <translation type="unfinished">Data ya Pochi</translation>
    </message>
    </context>
<context>
    <name>bitcoin-core</name>
    <message>
        <source>More than one onion bind address is provided. Using %s for the automatically created Tor onion service.</source>
        <translation type="unfinished">Zaidi ya anuani moja ya onion bind imetolewa. Inatumia %skwa ajili ya huduma ya Tor onion inayotengeneza kiotomatiki. </translation>
    </message>
    <message>
        <source>Cannot resolve -%s address: '%s'</source>
        <translation type="unfinished">Imeshindwa kutatua -%s anuani: '%s'</translation>
    </message>
    <message>
        <source>Error: Address book data in wallet cannot be identified to belong to migrated wallets</source>
        <translation type="unfinished">Hitilafu: Data za kitabu cha anunai katika pochi haziwezi kutambulika kuwa ni ya pochi zilizohamia.</translation>
    </message>
    <message>
        <source>default wallet</source>
        <translation type="unfinished">mkoba chaguo-msingi</translation>
    </message>
    <message>
        <source>Error: No %s addresses available.</source>
        <translation type="unfinished">Hitilafu: Hamna anuani zilizopo %s.</translation>
    </message>
    <message>
        <source>Error: Unable to remove watchonly address book data</source>
        <translation type="unfinished">Hitilafu: Imeshindwa kuondoa data katika kitabu cha anuani ya kutazama tu</translation>
    </message>
    <message>
        <source>Invalid -i2psam address or hostname: '%s'</source>
        <translation type="unfinished">Anuani ya -i2psam au jina la mwenyeji ni batili: '%s'</translation>
    </message>
    <message>
        <source>Invalid -onion address or hostname: '%s'</source>
        <translation type="unfinished">Anuani ya onion au jina la mwenyeji ni batili: '%s'</translation>
    </message>
    <message>
        <source>Invalid -proxy address or hostname: '%s'</source>
        <translation type="unfinished">Anuani ya wakala au jina la mwenyeji ni batili: '%s'</translation>
    </message>
    <message>
        <source>Loading P2P addresses…</source>
        <translation type="unfinished">Tunapakia anuani za P2P</translation>
    </message>
    <message>
        <source>No addresses available</source>
        <translation type="unfinished">Hakuna anuani zinazopatikana</translation>
    </message>
    <message>
        <source>Transaction needs a change address, but we can't generate it.</source>
        <translation type="unfinished">Muamala unahitaji mabadiliko ya anuani, lakini hatuwezi kuitengeneza.</translation>
    </message>
    <message>
        <source>Unknown address type '%s'</source>
        <translation type="unfinished">Aina ya anuani haifahamiki '%s'</translation>
    </message>
    <message>
        <source>Verifying wallet(s)…</source>
        <translation type="unfinished">Kuthibitisha mkoba/mikoba</translation>
    </message>
    </context>
</TS>